@@ -2,10 +2,10 @@ package Acme::MorningMusume::Base;
 
 use strict;
 use warnings;
-use Date::Simple ();
+use DateTime;
 use base qw(Class::Accessor);
 
-our $VERSION = '0.07';
+our $VERSION = '0.16';
 
 __PACKAGE__->mk_accessors(qw(
     name_ja
@@ -33,11 +33,6 @@ sub new {
     return $self;
 }
 
-sub images {
-    my ($self, %arg) = @_;
-    return $self->{_ua}->search($self->name_ja, %arg);
-}
-
 sub _initialize {
     my $self = shift;
     my %info = $self->info;
@@ -46,16 +41,13 @@ sub _initialize {
     $self->{name_ja} = $self->family_name_ja.$self->first_name_ja;
     $self->{name_en} = $self->first_name_en.' '.$self->family_name_en;
     $self->{age}     = $self->_calculate_age;
-    $self->{_ua}     = WWW::Google::Images::Ja->new(
-        server => 'images.google.co.jp'
-    );
 
     return 1;
 }
 
 sub _calculate_age {
     my $self  = shift;
-    my $today = Date::Simple::today;
+    my $today = DateTime->today;
 
     if (($today->month - $self->birthday->month) >= 0) {
         if (($today->day - $self->birthday->day  ) >= 0) {
@@ -68,36 +60,15 @@ sub _calculate_age {
     }
 }
 
-# wrapper for WWW::Google::Images to support a utf-8 encoded query
-package WWW::Google::Images::Ja;
+sub _datetime_from_date {
+    my ($self, $date) = @_;
+    my ($year, $month, $day) = ($date =~ /(\d{4})-(\d{2})-(\d{2})/);
 
-use base qw(WWW::Google::Images);
-
-sub search {
-    my ($self, $query, %arg) = @_;
-
-    $arg{limit} = 10 unless defined $arg{limit};
-    $self->{_agent}->get($self->{_server});
-    $self->{_agent}->submit_form(
-        form_number => 1,
-        fields      => {
-            ie => 'UTF-8',
-            hl => 'ja',
-            q  => $query,
-        }
+    DateTime->new(
+        year  => $year,
+        month => $month,
+        day   => $day,
     );
-
-    my @images;
-    my $page = 1;
-
-    LOOP: {
-        do {
-            push(@images, $self->_extract_images(($arg{limit} ? $arg{limit} - @images : 0), %arg));
-            last if $arg{limit} && @images == $arg{limit};
-        } while ($self->_next_page(++$page));
-    }
-
-    return WWW::Google::Images::SearchResult->new($self->{_agent}, @images);
 }
 
 1;
@@ -127,23 +98,13 @@ member of Morning Musume
       my $first_name_en  = $member->first_name_en;
       my $family_name_en = $member->family_name_en;
       my $nick           = $member->nick;           # arrayref
-      my $birthday       = $member->birthday;       # Date::Simple object
+      my $birthday       = $member->birthday;       # DateTime object
       my $age            = $member->age;
       my $blood_type     = $member->blood_type;
       my $hometown       = $member->hometown;
       my $emoticon       = $member->emoticon;       # arrayref
       my $class          = $member->class;
-      my $graduate_date  = $member->graduate_date;  # Date::Simple object
-
-      my $count;
-      my $images = $member->images(limit => 5);
-      while (my $image = $images->next) {
-          $count++;
-          my $content_url = $image->content_url;
-          my $context_url = $image->context_url;
-          $image->save_content(base => 'image' . $count);
-          $image->save_context(base => 'page'  . $count);
-      }
+      my $graduate_date  = $member->graduate_date;  # DateTime object
   }
 
 =head1 DESCRIPTION
@@ -151,21 +112,6 @@ member of Morning Musume
 Acme::MorningMusume::Base is a baseclass of the class represents each
 member of Morning Musume.
 
-=head1 METHODS
-
-=head2 images ( [ %arg ] )
-
-=over 4
-
-  # %arg can be passed in the same as the WWW::Google::Image::search method
-  my $images = $member->images(limit => 5);
-
-Performs a search for I<$member>'s name using Google, and returns a
-L<WWW::Google::Images::SearchResult> object. See the documentation of
-L<WWW::Google::Images> for details.
-
-=back
-
 =head1 ACCESSORS
 
 =head2 name_ja
@@ -200,9 +146,7 @@ L<WWW::Google::Images> for details.
 
 =over 4
 
-=item * L<Date::Simple>
-
-=item * L<WWW::Google::Images>
+=item * L<DateTime>
 
 =back
 
