@@ -5,7 +5,7 @@ use warnings;
 
 use base qw(Acme::MorningMusume::Base);
 
-our $VERSION = '0.04';
+our $VERSION = '0.16';
 
 sub info {
     return (
@@ -14,12 +14,12 @@ sub info {
         first_name_en  => 'Miki',
         family_name_en => 'Fujimoto',
         nick           => [qw(ミキティ 美貴帝 美貴様)],
-        birthday       => Date::Simple->new('1985-02-26'),
+        birthday       => $_[0]->_datetime_from_date('1985-02-26'),
         blood_type     => 'A',
         hometown       => '北海道',
         emoticon       => ['ゝ＇v＇丿'],
         class          => 6,
-        graduate_date  => Date::Simple->new('2007-06-01'),
+        graduate_date  => $_[0]->_datetime_from_date('2007-06-01'),
     );
 }
 
