@@ -5,7 +5,7 @@ use warnings;
 
 use base qw(Acme::MorningMusume::Base);
 
-our $VERSION = '0.03';
+our $VERSION = '0.16';
 
 sub info {
     return (
@@ -14,12 +14,12 @@ sub info {
         first_name_en  => 'Sayaka',
         family_name_en => 'Ichii',
         nick           => [qw(かあさん ちゃむ)],
-        birthday       => Date::Simple->new('1983-12-31'),
+        birthday       => $_[0]->_datetime_from_date('1983-12-31'),
         blood_type     => 'A',
         hometown       => '千葉県',
         emoticon       => ['ヽ^∀^ノ'],
         class          => 2,
-        graduate_date  => Date::Simple->new('2000-05-12'),
+        graduate_date  => $_[0]->_datetime_from_date('2000-05-12'),
     );
 }
 
