@@ -5,7 +5,7 @@ use warnings;
 
 use base qw(Acme::MorningMusume::Base);
 
-our $VERSION = '0.01';
+our $VERSION = '0.16';
 
 sub info {
     return (
@@ -14,7 +14,7 @@ sub info {
         first_name_en  => 'Ayumi',
         family_name_en => 'Ishida',
         nick           => [qw(だーいし あゆみん)],
-        birthday       => Date::Simple->new('1997-01-07'),
+        birthday       => $_[0]->_datetime_from_date('1997-01-07'),
         blood_type     => 'O',
         hometown       => '宮城県',
         emoticon       => [''],
