@@ -5,7 +5,7 @@ use warnings;
 
 use base qw(Acme::MorningMusume::Base);
 
-our $VERSION = '0.03';
+our $VERSION = '0.16';
 
 sub info {
     return (
@@ -14,12 +14,12 @@ sub info {
         first_name_en  => 'Aya',
         family_name_en => 'Ishiguro',
         nick           => [qw(あやっぺ)],
-        birthday       => Date::Simple->new('1978-05-12'),
+        birthday       => $_[0]->_datetime_from_date('1978-05-12'),
         blood_type     => 'A',
         hometown       => '北海道',
         emoticon       => ['（ ` ･ゝ´）'],
         class          => 1,
-        graduate_date  => Date::Simple->new('2000-01-07'),
+        graduate_date  => $_[0]->_datetime_from_date('2000-01-07'),
     );
 }
 
