@@ -5,7 +5,7 @@ use warnings;
 
 use base qw(Acme::MorningMusume::Base);
 
-our $VERSION = '0.04';
+our $VERSION = '0.16';
 
 sub info {
     return (
@@ -14,12 +14,12 @@ sub info {
         first_name_en  => 'Rika',
         family_name_en => 'Ishikawa',
         nick           => [qw(りかっち チャーミー)],
-        birthday       => Date::Simple->new('1985-01-19'),
+        birthday       => $_[0]->_datetime_from_date('1985-01-19'),
         blood_type     => 'A',
         hometown       => '神奈川県',
         emoticon       => ['（ ＾▽＾）'],
         class          => 4,
-        graduate_date  => Date::Simple->new('2005-05-07'),
+        graduate_date  => $_[0]->_datetime_from_date('2005-05-07'),
     );
 }
 
