@@ -5,7 +5,7 @@ use warnings;
 
 use base qw(Acme::MorningMusume::Base);
 
-our $VERSION = '0.03';
+our $VERSION = '0.16';
 
 sub info {
     return (
@@ -14,12 +14,12 @@ sub info {
         first_name_en  => 'Ai',
         family_name_en => 'Kago',
         nick           => [qw(あいぼん)],
-        birthday       => Date::Simple->new('1988-02-07'),
+        birthday       => $_[0]->_datetime_from_date('1988-02-07'),
         blood_type     => 'AB',
         hometown       => '奈良県',
         emoticon       => ['（ ‘д‘ ）'],
         class          => 4,
-        graduate_date  => Date::Simple->new('2004-08-01'),
+        graduate_date  => $_[0]->_datetime_from_date('2004-08-01'),
     );
 }
 
