@@ -5,7 +5,7 @@ use warnings;
 
 use base qw(Acme::MorningMusume::Base);
 
-our $VERSION = '0.04';
+our $VERSION = '0.16';
 
 sub info {
     return (
@@ -14,12 +14,12 @@ sub info {
         first_name_en  => 'Eri',
         family_name_en => 'Kamei',
         nick           => [qw(えりりん)],
-        birthday       => Date::Simple->new('1988-12-23'),
+        birthday       => $_[0]->_datetime_from_date('1988-12-23'),
         blood_type     => 'AB',
         hometown       => '東京都',
         emoticon       => ['ﾉﾉ*＾ｰ＾)'],
         class          => 6,
-        graduate_date  => Date::Simple->new('2010-12-15'),
+        graduate_date  => $_[0]->_datetime_from_date('2010-12-15'),
     );
 }
 
