@@ -5,7 +5,7 @@ use warnings;
 
 use base qw(Acme::MorningMusume::Base);
 
-our $VERSION = '0.03';
+our $VERSION = '0.16';
 
 sub info {
     return (
@@ -14,7 +14,7 @@ sub info {
         first_name_en  => 'Sayumi',
         family_name_en => 'Michishige',
         nick           => [qw(さゆみん)],
-        birthday       => Date::Simple->new('1989-07-13'),
+        birthday       => $_[0]->_datetime_from_date('1989-07-13'),
         blood_type     => 'A',
         hometown       => '山口県',
         emoticon       => ['从*・ 。・从'],
