@@ -5,7 +5,7 @@ use warnings;
 
 use base qw(Acme::MorningMusume::Base);
 
-our $VERSION = '0.03';
+our $VERSION = '0.16';
 
 sub info {
     return (
@@ -14,12 +14,12 @@ sub info {
         first_name_en  => 'Yuko',
         family_name_en => 'Nakazawa',
         nick           => [qw(姐さん)],
-        birthday       => Date::Simple->new('1973-06-19'),
+        birthday       => $_[0]->_datetime_from_date('1973-06-19'),
         blood_type     => 'O',
         hometown       => '京都府',
         emoticon       => ['从´∀｀从', '从#~∀~#从'],
         class          => 1,
-        graduate_date  => Date::Simple->new('2001-04-15'),
+        graduate_date  => $_[0]->_datetime_from_date('2001-04-15'),
     );
 }
 
