@@ -5,7 +5,7 @@ use warnings;
 
 use base qw(Acme::MorningMusume::Base);
 
-our $VERSION = '0.04';
+our $VERSION = '0.16';
 
 sub info {
     return (
@@ -14,12 +14,12 @@ sub info {
         first_name_en  => 'Risa',
         family_name_en => 'Niigaki',
         nick           => [qw(垣さん お豆ちゃん)],
-        birthday       => Date::Simple->new('1988-10-20'),
+        birthday       => $_[0]->_datetime_from_date('1988-10-20'),
         blood_type     => 'B',
         hometown       => '神奈川県',
         emoticon       => ['(・e・)', '（ё）'],
         class          => 5,
-        graduate_date  => Date::Simple->new('2012-05-18'),
+        graduate_date  => $_[0]->_datetime_from_date('2012-05-18'),
     );
 }
 
