@@ -5,7 +5,7 @@ use warnings;
 
 use base qw(Acme::MorningMusume::Base);
 
-our $VERSION = '0.04';
+our $VERSION = '0.16';
 
 sub info {
     return (
@@ -14,12 +14,12 @@ sub info {
         first_name_en  => 'Makoto',
         family_name_en => 'Ogawa',
         nick           => [qw(マコッちゃん)],
-        birthday       => Date::Simple->new('1987-10-29'),
+        birthday       => $_[0]->_datetime_from_date('1987-10-29'),
         blood_type     => 'O',
         hometown       => '新潟県',
         emoticon       => ['∬∬ ´◇｀)'],
         class          => 5,
-        graduate_date  => Date::Simple->new('2006-08-27'),
+        graduate_date  => $_[0]->_datetime_from_date('2006-08-27'),
     );
 }
 
