@@ -5,7 +5,7 @@ use warnings;
 
 use base qw(Acme::MorningMusume::Base);
 
-our $VERSION = '0.03';
+our $VERSION = '0.16';
 
 sub info {
     return (
@@ -14,12 +14,12 @@ sub info {
         first_name_en  => 'Kei',
         family_name_en => 'Yasuda',
         nick           => [qw(けいちゃん)],
-        birthday       => Date::Simple->new('1980-12-06'),
+        birthday       => $_[0]->_datetime_from_date('1980-12-06'),
         blood_type     => 'A',
         hometown       => '千葉県',
         emoticon       => ['（　｀.∀´）'],
         class          => 2,
-        graduate_date  => Date::Simple->new('2003-05-05'),
+        graduate_date  => $_[0]->_datetime_from_date('2003-05-05'),
     );
 }
 
